@@ -179,7 +179,7 @@ def execute_scratch_cell(code, raw_args, kernel):
                 SOS_SECTION_HEADER.match(line) or line.startswith('%from') or
                 line.startswith('%include') for line in code.splitlines()
         ]):
-            code = f'[cell_{kernel.cell_id[:8] if kernel and kernel.cell_id else "0"}]\n' + code
+            code = f'[cell_{str(kernel.cell_id)[:8] if kernel and kernel.cell_id else "0"}]\n' + code
             script = SoS_Script(content=code)
         else:
             return
